==> haskell-cryptohash-conduit-0.1.1-277-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-conduit
version: 0.1.1
id: cryptohash-conduit-0.1.1-9fs2mBaVx5V12FjGdjCe3F
key: cryptohash-conduit-0.1.1-9fs2mBaVx5V12FjGdjCe3F
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-cryptohash-conduit
synopsis: cryptohash conduit
description:
    Support all the @cryptohash@ package using conduits from
    the @conduit@ package.
category: Cryptography, Conduit
abi: af3b2a15c092c2e4a212119d924e2f63
exposed: True
exposed-modules:
    Crypto.Hash.Conduit
import-dirs: /usr/lib/ghc-8.6.5/site-local/cryptohash-conduit-0.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/cryptohash-conduit-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/cryptohash-conduit-0.1.1
hs-libraries: HScryptohash-conduit-0.1.1-9fs2mBaVx5V12FjGdjCe3F
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1.1-Hp9wSvoIvGH1D2bMBRqJC
    conduit-extra-1.3.1.1-7XA4NerKXBpBM0lrNiOBvC
    cryptohash-0.11.9-7PRo03aB2Gz5H0SIVUcjNS
    resourcet-1.2.2-DSV6hnFiraKK5yk15oWe4c transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-cryptohash-conduit/html/cryptohash-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-conduit-0.1.1-279-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-conduit
version: 0.1.1
id: cryptohash-conduit-0.1.1-6yrymcKfOn7BU1nxJvHnvK
key: cryptohash-conduit-0.1.1-6yrymcKfOn7BU1nxJvHnvK
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-cryptohash-conduit
synopsis: cryptohash conduit
description:
    Support all the @cryptohash@ package using conduits from
    the @conduit@ package.
category: Cryptography, Conduit
abi: 9a293caff9cb121b23cf5eb0fc178340
exposed: True
exposed-modules:
    Crypto.Hash.Conduit
import-dirs: /usr/lib/ghc-8.6.5/site-local/cryptohash-conduit-0.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/cryptohash-conduit-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/cryptohash-conduit-0.1.1
hs-libraries: HScryptohash-conduit-0.1.1-6yrymcKfOn7BU1nxJvHnvK
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1.1-GP6MsgQ2BS48W03o5Iyugz
    conduit-extra-1.3.1.1-BpNAtWN1v251tAneLnGOdO
    cryptohash-0.11.9-7PRo03aB2Gz5H0SIVUcjNS
    resourcet-1.2.2-DSV6hnFiraKK5yk15oWe4c transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-cryptohash-conduit/html/cryptohash-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
